#===============================================================================
#
# Copyright (c) 2014 Qualcomm Technologies, Inc. All Rights Reserved.
# Qualcomm Technologies Proprietary and Confidential.
#
#===============================================================================

"""Contains constants related to the cfgparser package.

Constants relate to:

#. Common constants
#. Auto-generated FM XML Parser - auto_gen_xml_config
"""


import os


#------------------------------------------------------------------------------
# Common constants
#------------------------------------------------------------------------------
# Absolute path of the package
PACKAGE_PATH = os.path.dirname(os.path.realpath(__file__))

# Name of the root node of any config related objects
ROOTNODE_NAME = 'secdat'

SECDAT_REVISION_ONE = 1
SECDAT_REVISION_TWO = 2

KEYPROVISION_SEGMENT = 1
EFUSE_SEGMENT = 0
ONE_SEGMENT = 1
TWO_SEGMENTS = 2
ONE_SEG_OFFSET = 56
FOOTER_SIZE = 32
TWO_SEGS_HEADER_SIZE = 64
SEG_INFO_SIZE = 8
SEG_START_ADDR = 56
DEFAULT_SEG_ATTR = 0

FUSEBLOWER = 'fuseblower'
KEYPROVISION = 'keyprovision'

HDR_FMT = 'IIIIIIIIIIII'
SEGINFO_FMT = 'II'

#------------------------------------------------------------------------------
# Secdat constants from tzbsp_fuseprov.h
#------------------------------------------------------------------------------
FUSEPROV_INFO_MAX_SIZE      = 16
FUSEPROV_RESERVED_MAX_SIZE  = 4
FUSEPROV_HASH_MAX_SIZE      = 32
FUSEPROV_SECDAT_MAGIC1      = 0x3B7251CA
FUSEPROV_SECDAT_MAGIC2      = 0x2A126F29

CURRENT_SUPPORTED_SECDAT_REVISION       = 1
CURRENT_SUPPORTED_QFUSELIST_REVISION    = 1


fuseprov_region_etype_dict = \
{
    'FUSEPROV_REGION_TYPE_OEM_SEC_BOOT'     : 0x00000000,
    'FUSEPROV_REGION_TYPE_OEM_PK_HASH'      : 0x00000001,
    'FUSEPROV_REGION_TYPE_SEC_HW_KEY'       : 0x00000002,
    'FUSEPROV_REGION_TYPE_OEM_CONFIG'       : 0x00000003,
    'FUSEPROV_REGION_TYPE_READ_WRITE_PERM'  : 0x00000004,
    'FUSEPROV_REGION_TYPE_SPARE_REG19'      : 0x00000005,
    'FUSEPROV_REGION_TYPE_GENERAL'          : 0x00000006,
    'FUSEPROV_REGION_TYPE_FEC_EN'           : 0x00000007,
    'FUSEPROV_REGION_TYPE_ANTI_ROLLBACK_2'  : 0x00000008,
    'FUSEPROV_REGION_TYPE_ANTI_ROLLBACK_3'  : 0x00000009,
    'FUSEPROV_REGION_TYPE_MAX'              : 0x7FFFFFFF,
}

fuseprov_operation_etype_dict = \
{
    'FUSEPROV_OPERATION_TYPE_BLOW'          : 0x00000000,
    'FUSEPROV_OPERATION_TYPE_VERIFYMASK0'   : 0x00000001,
    'FUSEPROV_OPERATION_TYPE_MAX'           : 0x7FFFFFFF,
}

fuseprov_error_etype_dict = \
{
    'FUSEPROV_SUCCESS'                      : 0x00000000,
    'FUSEPROV_FAILURE'                      : 0x00000001,
    'FUSEPROV_INVALID_ARG'                  : 0x00000002,
    'FUSEPROV_NO_MEMORY'                    : 0x00000003,
    'FUSEPROV_SECDAT_MAGIC_MISMATCH'        : 0x00000004,
    'FUSEPROV_SECDAT_REV_NOT_SUPPORTED'     : 0x00000005,
    'FUSEPROV_SECDAT_SIZE_LEN_MISMATCH'     : 0x00000006,
    'FUSEPROV_QFPROM_READ_ERROR'            : 0x00000007,
    'FUSEPROV_QFUSE_REV_NOT_SUPPORTED'      : 0x00000008,
    'FUSEPROV_INVALID_HASH'                 : 0x00000009,
    'FUSEPROV_TZBSP_HASH_FAIL'              : 0x0000000A,
    'FUSEPROV_SECDAT_LOCK_BLOWN'            : 0x0000000B,
    'FUSEPROV_QFPROM_WRITE_ERROR'           : 0x0000000C,
    'FUSEPROV_SHK_RD_WR_DISABLE_BLOWN'      : 0x0000000D,
    'FUSEPROV_SHK_GENERATION_FAILED'        : 0x0000000E,
    'FUSEPROV_SHK_ALRDY_BLOWN'              : 0x0000000F,
    'FUSEPROV_SHK_RD_WR_MISMATCH'           : 0x00000010,
    'FUSEPROV_ERR_TYPE_MAX'                 : 0x7FFFFFFF
}


#------------------------------------------------------------------------------
# Mapping from the config values to the fuseprov values
#------------------------------------------------------------------------------

secdat_region_etype_dict = \
{
    'QFPROM_RAW_OEM_SEC_BOOT' : 'FUSEPROV_REGION_TYPE_OEM_SEC_BOOT',
    'QFPROM_RAW_OEM_PK_HASH' : 'FUSEPROV_REGION_TYPE_OEM_PK_HASH',
    'QFPROM_RAW_SEC_KEY_DERIVATION_KEY' : 'FUSEPROV_REGION_TYPE_SEC_HW_KEY',
    'QFPROM_RAW_OEM_CONFIG' : 'FUSEPROV_REGION_TYPE_OEM_CONFIG',
    'QFPROM_RAW_RD_WR_PERM' : 'FUSEPROV_REGION_TYPE_READ_WRITE_PERM',
    'QFPROM_RAW_SPARE_REG19' : 'FUSEPROV_REGION_TYPE_SPARE_REG19',
    'QFPROM_RAW_GENERAL' : 'FUSEPROV_REGION_TYPE_GENERAL',
    'QFPROM_RAW_FEC_EN' : 'FUSEPROV_REGION_TYPE_FEC_EN',
    'QFPROM_RAW_ANTI_ROLLBACK_2' : 'FUSEPROV_REGION_TYPE_ANTI_ROLLBACK_2',
    'QFPROM_RAW_ANTI_ROLLBACK_3' : 'FUSEPROV_REGION_TYPE_ANTI_ROLLBACK_3',
    'QFPROM_RAW_CUST_KEY1_L1' : 'FUSEPROV_REGION_TYPE_GENERAL',
    'QFPROM_RAW_CUST_KEY1_ROT' : 'FUSEPROV_REGION_TYPE_GENERAL',
}

secdat_operation_etype_dict = \
{
    'BLOW' : 'FUSEPROV_OPERATION_TYPE_BLOW',
    'VERIFYMASK0' : 'FUSEPROV_OPERATION_TYPE_VERIFYMASK0',
}


